==> apache-cassandra-4.0.19-src.tar.gz: apache-cassandra-4.0.19-src/src/java/org/apache/cassandra/tools/nodetool/HostStatWithPort.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.tools.nodetool;

import org.apache.cassandra.locator.InetAddressAndPort;

public class HostStatWithPort extends HostStat
{
    public final InetAddressAndPort endpointWithPort;

    public HostStatWithPort(String token, InetAddressAndPort endpoint, boolean resolveIp, Float owns)
    {
        super(token, endpoint.address, resolveIp, owns);
        this.endpointWithPort = endpoint;
    }

    public String ipOrDns()
    {
        return ipOrDns(true);
    }

    public String ipOrDns(boolean withPort)
    {
        if (!withPort)
            return super.ipOrDns();

        return resolveIp ?
               endpointWithPort.address.getHostName() + ':' + endpointWithPort.port :
               endpointWithPort.getHostAddressAndPort();
    }
}

==> apache-cassandra-4.1.10-src.tar.gz: apache-cassandra-4.1.10-src/src/java/org/apache/cassandra/tools/nodetool/HostStatWithPort.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.tools.nodetool;

import org.apache.cassandra.locator.InetAddressAndPort;

public class HostStatWithPort extends HostStat
{
    public final InetAddressAndPort endpointWithPort;

    public HostStatWithPort(String token, InetAddressAndPort endpoint, boolean resolveIp, Float owns)
    {
        super(token, endpoint.getAddress(), resolveIp, owns);
        this.endpointWithPort = endpoint;
    }

    public String ipOrDns()
    {
        return ipOrDns(true);
    }

    public String ipOrDns(boolean withPort)
    {
        if (!withPort)
            return super.ipOrDns();

        return resolveIp ?
               endpointWithPort.getAddress().getHostName() + ':' + endpointWithPort.getPort() :
               endpointWithPort.getHostAddressAndPort();
    }
}
